==> syncope-2.0.14-source-release.zip: syncope-2.0.14/common/lib/src/main/java/org/apache/syncope/common/lib/to/AccessTokenTO.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.common.lib.to;

import java.util.Date;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.syncope.common.lib.AbstractBaseBean;

@XmlRootElement(name = "accessToken")
@XmlType
public class AccessTokenTO extends AbstractBaseBean implements EntityTO {

    private static final long serialVersionUID = 6577639976115661357L;

    private String key;

    private String body;

    private Date expiryTime;

    private String owner;

    @Override
    public String getKey() {
        return key;
    }

    @Override
    public void setKey(final String key) {
        this.key = key;
    }

    public String getBody() {
        return body;
    }

    public void setBody(final String body) {
        this.body = body;
    }

    public Date getExpiryTime() {
        return expiryTime == null
                ? null
                : new Date(expiryTime.getTime());
    }

    public void setExpiryTime(final Date expiryTime) {
        this.expiryTime = expiryTime == null
                ? null
                : new Date(expiryTime.getTime());
    }

    public String getOwner() {
        return owner;
    }

    public void setOwner(final String owner) {
        this.owner = owner;
    }

}

==> syncope-2.1.5-source-release.zip: syncope-2.1.5/common/lib/src/main/java/org/apache/syncope/common/lib/to/AccessTokenTO.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.common.lib.to;

import java.util.Date;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.syncope.common.lib.BaseBean;

@XmlRootElement(name = "accessToken")
@XmlType
public class AccessTokenTO extends BaseBean implements EntityTO {

    private static final long serialVersionUID = 6577639976115661357L;

    private String key;

    private String body;

    private Date expiryTime;

    private String owner;

    @Override
    public String getKey() {
        return key;
    }

    @Override
    public void setKey(final String key) {
        this.key = key;
    }

    public String getBody() {
        return body;
    }

    public void setBody(final String body) {
        this.body = body;
    }

    public Date getExpiryTime() {
        return expiryTime == null
                ? null
                : new Date(expiryTime.getTime());
    }

    public void setExpiryTime(final Date expiryTime) {
        this.expiryTime = expiryTime == null
                ? null
                : new Date(expiryTime.getTime());
    }

    public String getOwner() {
        return owner;
    }

    public void setOwner(final String owner) {
        this.owner = owner;
    }

}
